==> haskell-http2-1.6.3-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.3
id: http2-1.6.3-Kvpwsy2PHd8Jk4MaDHzHlq
key: http2-1.6.3-Kvpwsy2PHd8Jk4MaDHzHlq
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library including frames, priority queues and HPACK
description:
    HTTP/2 library including frames, priority queues and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Types
abi: 625c419541bf941c406a6b5b878dd56f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http2-1.6.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/http2-1.6.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/http2-1.6.3
hs-libraries: HShttp2-1.6.3-Kvpwsy2PHd8Jk4MaDHzHlq
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu containers-0.5.7.1
    psqueues-0.2.2.3-GoHjRP8xRERFkN5Bs2DRqR
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-1.6.3-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.3
id: http2-1.6.3-FkRqMe3qhqb2c4ZZGBG7FS
key: http2-1.6.3-FkRqMe3qhqb2c4ZZGBG7FS
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library including frames, priority queues and HPACK
description:
    HTTP/2 library including frames, priority queues and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Types
abi: aa07de96f673f731e6106012822bf2a5
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http2-1.6.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/http2-1.6.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/http2-1.6.3
hs-libraries: HShttp2-1.6.3-FkRqMe3qhqb2c4ZZGBG7FS
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HwS3NhekiJcDT3x6QkJ9Xz containers-0.5.7.1
    psqueues-0.2.2.3-8KktaatqvmQ9bEbz13fJDx
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
